function [ f ] = CSTR_estado_estacionario(x)

V     =    7.08    ; % volume do reator [=] m3
ro    =   19.20    ; % [=] kmol/m3
Cp    =    1.815e5 ; % [=] J/(kmol.oC)
A     =    5.40    ; % rea de troca trmica [=] m2
roc   = 1000.00    ; % [=] kg/m3
ko    =    0.0744  ; % [=] m3/(s.kmol)
dHR   =   -9.86e7  ; % [=] J/kmol
U     = 3550.00    ; % [=] J/(s.m2.oC)
Vc    =    1.82    ; % [=] m3
Cpc   = 4184.00    ; % [=] K/(kg.oC)
E     =    1.182e7 ; % [=] J/kmol
Fcmax =    0.02    ; % [=] m3/s
Rg    = 8314.39    ; % [=] 
g     =    9.81    ; % [=] m/s2

Rt    = ( 2 * V / ( 2 * pi ) ) ^ (1/3) ; % Lmax = 2R , e L = 50% Lmax
At    = pi * Rt ^ 2                    ; % rea transversal do tanque (L=2R) [=] m2
Lt    = V / At                         ; % nvel de projeto [=] m

Ft    = 7.5e-3                   ; % vazo de descarga de projeto [=] m3/s
alfaL = Ft / sqrt( ro * g * Lt ) ; % constante de proporcionalidade para F

L   =   V / At  ; % [=] m
CAi =   2.88    ; % [=] kmol/m3
CBi =   0       ; % [=] kmol/m3
Ti  =  66       ; % [=] oC
Tci =  27       ; % [=] oC
Fi  =  7.5e-3   ; % [=] m3/h
Fci =  7.392e-3 ; % [=] m3/h
Fc  =  Fci      ;

F  = x(1) ;
CA = x(2) ;
CB = x(3) ;
T  = x(4) ;
Tc = x(5) ;

V        = At * L                               ;
ex       = exp( - E / ( Rg * ( T + 273.15 ) ) ) ;
k        = ko * ex                              ;
kCA      = k * CA                               ;
G        = kCA * CA                             ;
UA       = U * A                                ;
roCp     = ro * Cp                              ;
VroCp    = V * roCp                             ;
FiV      = Fi / V                               ;
FiVL     = FiV * L                              ;
FcVc     = Fc / Vc                              ;
VcrocCpc = Vc * roc * Cpc                       ;

f(1) =        ( Fi  - F  ) / At                                          ;
f(2) = FiV  * ( CAi - CA ) -       G                                     ;
f(3) = FiV  * ( CBi - CB ) +       G                                     ;
f(4) = FiV  * ( Ti  - T  ) - dHR * G / roCp - UA * ( T - Tc ) / VroCp    ;
f(5) = FcVc * ( Tci - Tc )                  + UA * ( T - Tc ) / VcrocCpc ;
